@@ -1,17 +1,28 @@
 #!/usr/bin/perl -I. -w
 
-package TimeAdapter;
-use base qw( Aw::Adapter );
+$| =1;
 
-require Aw;
-require Aw::Event;
+package TimeAdapter;
+
+use Aw;
+use Aw::Event;
+require Aw::Adapter;
+
+@TimeAdapter::ISA=qw(Aw::Adapter);
 
 
 my ($false, $true) = (0,1);
 
 #  for use in the AdapterDevKit::time event
-my $eventTime = new Aw::Date;   # should be empty and must be in the
-                                # scope of startup and createTimeEvent
+my $eventTime = new Aw::Date;   # should be empty and must be in the scope of startup and createTimeEvent
+
+sub beginTransaction {
+	my $self = shift;
+	my $transactionId = shift;
+	print "  Hello from beginTansaction Method\n";
+	print "  [",$transactionId,"]\n" if ( $transactionId );
+	$true;
+}
 
 
 
@@ -24,12 +35,13 @@ sub startup {
 
 
 	#  register the event
-	$self->addEvent( new Aw::EventType ( "AdapterDevKit::timeRequest" ) );
+	my $event = new Aw::EventType ( "AdapterDevKit::timeRequest" );
+	$self->addEvent( $event );
 
 	
 	if ( $self->isMaster ) {
 	 	#  set up the periodic publication of AdapterDevKit::time
-		my $event = new Aw::EventType ( "AdapterDevKit::time" );
+		$event = new Aw::EventType ( "AdapterDevKit::time" );
 	 	$event->isPublish ( $true );
 	 	$event->publishInterval ( 15 );
 	 	$event->nextPublish ( time );
@@ -41,13 +53,13 @@ sub startup {
     
 	#  set up subscriptions for the Adapter::lookup and Adapter::refresh events
 	
-	( $self->initStatusSubscriptions ) ? $false : $true ;  # init also does publishStatus
+	return ( $self->initStatusSubscriptions ) ? $false : $true ;  # init also does publishStatus
     
 }
 
 
 #
-#  A subroutine used by the call backs
+#  A subroutined used by the call backs
 #
 sub createTimeEvent {
 
@@ -113,7 +125,7 @@ sub processRequest {
 
 	my ( $self, $reqEvent, $eventDef ) = @_;
 
-	# print "Hello from processRequest Method\n";
+	print "Hello from processRequest Method\n";
 
 	my $reply = $self->createTimeEvent ( $self );
 
@@ -132,31 +144,26 @@ package main;
 
 main: {
 
-	#
-	# traditional style (use awAdapterLoadProperties):
-	#
-	my @properties =(
-	        'TimeAdapter',
-	        'test_broker@localhost:6449',
-	        0,
-	        # './adapters.cfg', # required if not in the system adapters.cfg
-	        'debug=1',
-	        'clientGroup=devkitAdapter',
-	        'adapterType=Adapter40',
-	        'messageCatalog=time_adapter'
+	my @properties = (
+	        # "XS Time Adapter",
+	        "TimeAdapter",
+	        "test_broker\@localhost:8849",
+	        "0",
+		"./adapters.cfg",
+	        "debug=1",
+	        "clientGroup=devkitAdapter",
+	        # "adapterType=time_adapter",
+	        "adapterType=Adapter40",
+	        "messageCatalog=time_adapter"
 	);
-	#
-	#  or use a hash!  no .cfg file needed:
-	#
-	my %properties		=(
+	my %properties = (
 	        clientId	=> 'TimeAdapter',
-	        broker		=> 'test_broker@localhost:6449',
+	        broker		=> "test\@localhost:7449",
 	        adapterId	=> 0,
 	        debug		=> 1,
 	        clientGroup	=> 'devkitAdapter',
 	        adapterType	=> 'Adapter40',
-	        messageCatalog	=> 'time_adapter'   # optional
-		# configFile	=> '/path/to/file'  # optional
+	        messageCatalog	=> 'time_adapter'
 	);
 
 
@@ -167,7 +174,7 @@ main: {
 
 
 	#
-	# Alternately, two steps...
+	# Alternately
 	#
 	# $adapter = new TimeAdapter;
 	# $adapter->loadProperties ( @properties );
@@ -197,32 +204,3 @@ main: {
 
 	print "\nRetval = $retVal\n";
 }
-
-__END__
-
-=head1 NAME
-
-time_adapter.pl - Perlized Version of the CADK Time Adapter.
-
-=head1 SYNOPSIS
-
-./time_adapter.pl
-
-=head1 DESCRIPTION
-
-This script is the analog of the ActiveWorks 3.0 and 4.0 ADK
-"time_adapter.c" and "TimeAdapter.java" adapters.  The script is the
-counterpart of the time_test.pl script.
-
-The AdapterDevKit::time, AdapterDevKit::timeRequest and the
-devkitAdapter client group are assumed already set in the target broker.
-
-=head1 AUTHOR
-
-Daniel Yacob Mekonnen,  L<Yacob@wMUsers.Com|mailto:Yacob@wMUsers.Com>
-
-=head1 SEE ALSO
-
-S<perl(1). ActiveWorks Supplied Documentation>
-
-=cut
